@@ -1,7 +1,6 @@
 import numpy
 import datetime
-from nfs_hj3415.db import Corps
-
+from nfsmi_hj3415.db import Corps, Settings
 import logging
 logger = logging.getLogger(__name__)
 formatter = logging.Formatter('%(levelname)s: [%(name)s] %(message)s')
